#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 arch-hs
version:              0.14.1
visibility:           public
id:                   arch-hs-0.14.1-Ed7JjkvjBWmBfknndAeqRU
key:                  arch-hs-0.14.1-Ed7JjkvjBWmBfknndAeqRU
license:              MIT
copyright:            (c) 2020-2022 berberman
maintainer:           berberman <berberman@yandex.com>
author:               berberman
homepage:             https://github.com/berberman/arch-hs
synopsis:             Distribute hackage packages to archlinux
description:
    @arch-hs@ is a command-line program, which simplifies the process of producing
    and maintaining haskell packages for archlinux distribution by automating the
    PKGBUILD generation with the dependency resolving and template filling. Currently,
    @arch-hs@ is unstable, so packagers should not trust it 100%, but always follow the
    <https://wiki.archlinux.org/index.php/Haskell_package_guidelines Haskell package guidelines>.

category:             Distribution
abi:                  8a5adf5b3aba9ff13e66fae457812172
exposed:              True
exposed-modules:
    Distribution.ArchHs.Aur Distribution.ArchHs.Compat
    Distribution.ArchHs.Core Distribution.ArchHs.DepCheck
    Distribution.ArchHs.Exception Distribution.ArchHs.ExtraDB
    Distribution.ArchHs.FilesDB Distribution.ArchHs.Hackage
    Distribution.ArchHs.Internal.Prelude Distribution.ArchHs.Local
    Distribution.ArchHs.Name Distribution.ArchHs.Options
    Distribution.ArchHs.PP Distribution.ArchHs.PkgBuild
    Distribution.ArchHs.PkgDesc Distribution.ArchHs.RDepCheck
    Distribution.ArchHs.Types Distribution.ArchHs.Utils

hidden-modules:
    Distribution.ArchHs.Internal.NamePresetLoader Paths_arch_hs

import-dirs:          /usr/lib/ghc-9.6.6/site-local/arch-hs-0.14.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/arch-hs-0.14.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/arch-hs-0.14.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/arch-hs
hs-libraries:         HSarch-hs-0.14.1-Ed7JjkvjBWmBfknndAeqRU
extra-libraries:      alpm
include-dirs:         /usr/lib/ghc-9.6.6/site-local/arch-hs-0.14.1/include
depends:
    Cabal-3.10.3.0 Diff-1.0-n0RmXNQVFrGyP2VCRbod4
    aeson-2.2.2.0-mVpxNJADFA3tVhrw9PzvG
    algebraic-graphs-0.8-52m4ZbQwMqP6Uys3wQXoFo
    arch-web-0.3.2-3smeMymdXbOqs5OysXWQo base-4.18.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-FIwCK0b1Hr15S6D1xh1znT
    conduit-extra-1.3.8-Ck6pOXJmJPw7MIsaJ1VnN1 containers-0.6.7
    deepseq-1.4.8.1 directory-1.3.8.5 filepath-1.4.300.1
    hackage-db-2.1.3-9Zm5Q6JZlFFCbZ9dOTneAh
    http-client-0.7.19-EUgGdw3KTvRKxRF4wbGFhk
    http-client-tls-0.3.6.4-H3zfj6u59LA6yzNQrvZrZx
    http-types-0.12.4-1B8W97d7Bm7JkBvipzT6Xa
    megaparsec-9.7.1-3v9USGunK8PJV50Lxdl0PB
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    microlens-th-0.4.3.17-1JCZcjTuCbDB2Q9keDntvT
    neat-interpolation-0.5.1.4-ACN2Jj3LsNs3n9lYte9Moa
    optparse-simple-0.1.1.4-EBstS3Sjg9C5IWrADBA9wp
    polysemy-1.9.2.0-2kvkBlrhmDn55JTi26wolz
    prettyprinter-1.7.2-1DGqCnBpxP9HlPCcGuqpc1
    prettyprinter-ansi-terminal-1.1.4-JHkdh8ZQnpYA1tQeTHAtKh
    servant-client-0.20.3.0-EO2Pu6qWCoCCQEJpEjKY8D
    split-0.2.5-3KQHz3VjCt4O3lCLzOFzl
    tar-conduit-0.4.1-5ih0nZ0z7DvJR90MfmKP3q template-haskell-2.20.0.0
    text-2.0.2

haddock-interfaces:   /usr/share/doc/arch-hs/html/arch-hs.haddock
haddock-html:         /usr/share/doc/arch-hs/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

